@@ -1,7 +1,16 @@
 # -------------------------------------------------------------------------
-# Copyright (c) Microsoft Corporation. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
+# Copyright (c) Microsoft.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 # --------------------------------------------------------------------------
 from azure.common import AzureException
 from dateutil import parser
@@ -17,7 +26,7 @@ from ..common._common_conversion import (
 )
 from ..common._deserialization import (
     _parse_properties,
-    _to_int,
+    _int_to_str,
     _parse_metadata,
     _convert_xml_to_signed_identifiers,
     _bool,
@@ -35,8 +44,6 @@ from .models import (
     PageBlobProperties,
     ResourceProperties,
     BlobPrefix,
-    AccountInformation,
-    UserDelegationKey,
 )
 from ._encryption import _decrypt_blob
 from ..common.models import _list
@@ -64,7 +71,7 @@ def _parse_page_properties(response):
     put_page = PageBlobProperties()
     put_page.last_modified = parser.parse(response.headers.get('last-modified'))
     put_page.etag = response.headers.get('etag')
-    put_page.sequence_number = _to_int(response.headers.get('x-ms-blob-sequence-number'))
+    put_page.sequence_number = _int_to_str(response.headers.get('x-ms-blob-sequence-number'))
 
     return put_page
 
@@ -76,8 +83,8 @@ def _parse_append_block(response):
     append_block = AppendBlockProperties()
     append_block.last_modified = parser.parse(response.headers.get('last-modified'))
     append_block.etag = response.headers.get('etag')
-    append_block.append_offset = _to_int(response.headers.get('x-ms-blob-append-offset'))
-    append_block.committed_block_count = _to_int(response.headers.get('x-ms-blob-committed-block-count'))
+    append_block.append_offset = _int_to_str(response.headers.get('x-ms-blob-append-offset'))
+    append_block.committed_block_count = _int_to_str(response.headers.get('x-ms-blob-committed-block-count'))
 
     return append_block
 
@@ -97,7 +104,7 @@ def _parse_lease(response):
     '''
     lease = {'time': response.headers.get('x-ms-lease-time')}
     if lease['time']:
-        lease['time'] = _to_int(lease['time'])
+        lease['time'] = _int_to_str(lease['time'])
 
     lease['id'] = response.headers.get('x-ms-lease-id')
 
@@ -167,8 +174,6 @@ def _convert_xml_to_containers(response):
             <LeaseState>available | leased | expired | breaking | broken</LeaseState>
             <LeaseDuration>infinite | fixed</LeaseDuration>
             <PublicAccess>blob | container</PublicAccess>
-            <HasImmutabilityPolicy>true | false</HasImmutabilityPolicy>
-            <HasLegalHold>true | false</HasLegalHold>
           </Properties>
           <Metadata>
             <metadata-name>value</metadata-name>
@@ -209,8 +214,6 @@ def _convert_xml_to_containers(response):
         container.properties.lease_state = properties_element.findtext('LeaseState')
         container.properties.lease_duration = properties_element.findtext('LeaseDuration')
         container.properties.public_access = properties_element.findtext('PublicAccess')
-        container.properties.has_immutability_policy = properties_element.findtext('HasImmutabilityPolicy')
-        container.properties.has_legal_hold = properties_element.findtext('HasLegalHold')
 
         # Add container to list
         containers.append(container)
@@ -221,9 +224,9 @@ def _convert_xml_to_containers(response):
 LIST_BLOBS_ATTRIBUTE_MAP = {
     'Last-Modified': (None, 'last_modified', parser.parse),
     'Etag': (None, 'etag', _to_str),
-    'x-ms-blob-sequence-number': (None, 'sequence_number', _to_int),
+    'x-ms-blob-sequence-number': (None, 'sequence_number', _int_to_str),
     'BlobType': (None, 'blob_type', _to_str),
-    'Content-Length': (None, 'content_length', _to_int),
+    'Content-Length': (None, 'content_length', _int_to_str),
     'ServerEncrypted': (None, 'server_encrypted', _bool),
     'Content-Type': ('content_settings', 'content_type', _to_str),
     'Content-Encoding': ('content_settings', 'content_encoding', _to_str),
@@ -244,9 +247,6 @@ LIST_BLOBS_ATTRIBUTE_MAP = {
     'AccessTierChangeTime': (None, 'blob_tier_change_time', parser.parse),
     'AccessTierInferred': (None, 'blob_tier_inferred', _bool),
     'ArchiveStatus': (None, 'rehydration_status', _to_str),
-    'DeletedTime': (None, 'deleted_time', parser.parse),
-    'RemainingRetentionDays': (None, 'remaining_retention_days', _to_int),
-    'Creation-Time': (None, 'creation_time', parser.parse),
 }
 
 
@@ -261,7 +261,6 @@ def _convert_xml_to_blob_list(response):
       <Blobs>
         <Blob>
           <Name>blob-name</name>
-          <Deleted>true</Deleted>
           <Snapshot>date-time-value</Snapshot>
           <Properties>
             <Last-Modified>date-time-value</Last-Modified>
@@ -286,9 +285,6 @@ def _convert_xml_to_blob_list(response):
             <AccessTier>P4 | P6 | P10 | P20 | P30 | P40 | P50 | P60 | Archive | Cool | Hot</AccessTier>
             <AccessTierChangeTime>date-time-value</AccessTierChangeTime>
             <AccessTierInferred>true</AccessTierInferred>
-            <DeletedTime>datetime</DeletedTime>
-            <RemainingRetentionDays>int</RemainingRetentionDays>
-            <Creation-Time>date-time-value</Creation-Time>
           </Properties>
           <Metadata>   
             <Name>value</Name>
@@ -322,10 +318,6 @@ def _convert_xml_to_blob_list(response):
         blob.name = blob_element.findtext('Name')
         blob.snapshot = blob_element.findtext('Snapshot')
 
-        deleted = blob_element.findtext('Deleted')
-        if deleted:
-            blob.deleted = _bool(deleted)
-
         # Properties
         properties_element = blob_element.find('Properties')
         if properties_element is not None:
@@ -352,77 +344,6 @@ def _convert_xml_to_blob_list(response):
     return blob_list
 
 
-def _convert_xml_to_blob_name_list(response):
-    '''
-    <?xml version="1.0" encoding="utf-8"?>
-    <EnumerationResults ServiceEndpoint="http://myaccount.blob.core.windows.net/" ContainerName="mycontainer">
-      <Prefix>string-value</Prefix>
-      <Marker>string-value</Marker>
-      <MaxResults>int-value</MaxResults>
-      <Delimiter>string-value</Delimiter>
-      <Blobs>
-        <Blob>
-          <Name>blob-name</name>
-          <Deleted>true</Deleted>
-          <Snapshot>date-time-value</Snapshot>
-          <Properties>
-            <Last-Modified>date-time-value</Last-Modified>
-            <Etag>etag</Etag>
-            <Content-Length>size-in-bytes</Content-Length>
-            <Content-Type>blob-content-type</Content-Type>
-            <Content-Encoding />
-            <Content-Language />
-            <Content-MD5 />
-            <Cache-Control />
-            <x-ms-blob-sequence-number>sequence-number</x-ms-blob-sequence-number>
-            <BlobType>BlockBlob|PageBlob|AppendBlob</BlobType>
-            <LeaseStatus>locked|unlocked</LeaseStatus>
-            <LeaseState>available | leased | expired | breaking | broken</LeaseState>
-            <LeaseDuration>infinite | fixed</LeaseDuration>
-            <CopyId>id</CopyId>
-            <CopyStatus>pending | success | aborted | failed </CopyStatus>
-            <CopySource>source url</CopySource>
-            <CopyProgress>bytes copied/bytes total</CopyProgress>
-            <CopyCompletionTime>datetime</CopyCompletionTime>
-            <CopyStatusDescription>error string</CopyStatusDescription>
-            <AccessTier>P4 | P6 | P10 | P20 | P30 | P40 | P50 | P60 | Archive | Cool | Hot</AccessTier>
-            <AccessTierChangeTime>date-time-value</AccessTierChangeTime>
-            <AccessTierInferred>true</AccessTierInferred>
-            <DeletedTime>datetime</DeletedTime>
-            <RemainingRetentionDays>int</RemainingRetentionDays>
-            <Creation-Time>date-time-value</Creation-Time>
-          </Properties>
-          <Metadata>   
-            <Name>value</Name>
-          </Metadata>
-        </Blob>
-        <BlobPrefix>
-          <Name>blob-prefix</Name>
-        </BlobPrefix>
-      </Blobs>
-      <NextMarker />
-    </EnumerationResults>
-    '''
-    if response is None or response.body is None:
-        return None
-
-    blob_list = _list()
-    list_element = ETree.fromstring(response.body)
-
-    setattr(blob_list, 'next_marker', list_element.findtext('NextMarker'))
-
-    blobs_element = list_element.find('Blobs')
-    blob_prefix_elements = blobs_element.findall('BlobPrefix')
-    if blob_prefix_elements is not None:
-        for blob_prefix_element in blob_prefix_elements:
-            blob_list.append(blob_prefix_element.findtext('Name'))
-
-    for blob_element in blobs_element.findall('Blob'):
-        blob_list.append(blob_element.findtext('Name'))
-
-    return blob_list
-
-
 def _convert_xml_to_block_list(response):
     '''
     <?xml version="1.0" encoding="utf-8"?>
@@ -513,44 +434,3 @@ def _convert_xml_to_page_ranges(response):
         )
 
     return page_list
-
-
-def _parse_account_information(response):
-    account_info = AccountInformation()
-    account_info.sku_name = response.headers['x-ms-sku-name']
-    account_info.account_kind = response.headers['x-ms-account-kind']
-
-    return account_info
-
-
-def _convert_xml_to_user_delegation_key(response):
-    """
-    <?xml version="1.0" encoding="utf-8"?>
-    <UserDelegationKey>
-        <SignedOid> Guid </SignedOid>
-        <SignedTid> Guid </SignedTid>
-        <SignedStart> String, formatted ISO Date </SignedStart>
-        <SignedExpiry> String, formatted ISO Date </SignedExpiry>
-        <SignedService>b</SignedService>
-        <SignedVersion> String, rest api version used to create delegation key </SignedVersion>
-        <Value>Ovg+o0K/0/2V8upg7AwlyAPCriEcOSXKuBu2Gv/PU70Y7aWDW3C2ZRmw6kYWqPWBaM1GosLkcSZkgsobAlT+Sw==</value>
-    </UserDelegationKey >
-
-    Converts xml response to UserDelegationKey class.
-    """
-
-    if response is None or response.body is None:
-        return None
-
-    delegation_key = UserDelegationKey()
-
-    key_element = ETree.fromstring(response.body)
-    delegation_key.signed_oid = key_element.findtext('SignedOid')
-    delegation_key.signed_tid = key_element.findtext('SignedTid')
-    delegation_key.signed_start = key_element.findtext('SignedStart')
-    delegation_key.signed_expiry = key_element.findtext('SignedExpiry')
-    delegation_key.signed_service = key_element.findtext('SignedService')
-    delegation_key.signed_version = key_element.findtext('SignedVersion')
-    delegation_key.value = key_element.findtext('Value')
-
-    return delegation_key
