@@ -78,9 +78,9 @@ class PageBlobService(BaseBlobService):
 
     MAX_PAGE_SIZE = 4 * 1024 * 1024
 
-    def __init__(self, account_name=None, account_key=None, sas_token=None, is_emulated=False,
-                 protocol=DEFAULT_PROTOCOL, endpoint_suffix=SERVICE_HOST_BASE, custom_domain=None,
-                 request_session=None, connection_string=None, socket_timeout=None, token_credential=None):
+    def __init__(self, account_name=None, account_key=None, sas_token=None,
+                 is_emulated=False, protocol=DEFAULT_PROTOCOL, endpoint_suffix=SERVICE_HOST_BASE,
+                 custom_domain=None, request_session=None, connection_string=None, socket_timeout=None):
         '''
         :param str account_name:
             The storage account name. This is used to authenticate requests 
@@ -119,15 +119,11 @@ class PageBlobService(BaseBlobService):
         :param int socket_timeout:
             If specified, this will override the default socket timeout. The timeout specified is in seconds.
             See DEFAULT_SOCKET_TIMEOUT in _constants.py for the default value.
-        :param token_credential:
-            A token credential used to authenticate HTTPS requests. The token value
-            should be updated before its expiration.
-        :type `~azure.storage.common.TokenCredential`
         '''
         self.blob_type = _BlobTypes.PageBlob
         super(PageBlobService, self).__init__(
             account_name, account_key, sas_token, is_emulated, protocol, endpoint_suffix,
-            custom_domain, request_session, connection_string, socket_timeout, token_credential)
+            custom_domain, request_session, connection_string, socket_timeout)
 
     def create_blob(
             self, container_name, blob_name, content_length, content_settings=None,
