@@ -14,6 +14,7 @@ from time import sleep
 import requests
 from azure.common import (
     AzureException,
+    AzureHttpError,
 )
 
 from ._constants import (
@@ -39,6 +40,7 @@ from .models import (
     _OperationContext,
 )
 from .retry import ExponentialRetry
+from io import UnsupportedOperation
 
 
 class StorageClient(object):
@@ -68,10 +70,10 @@ class StorageClient(object):
         reading from secondary.
     :ivar function(context) retry:
         A function which determines whether to retry. Takes as a parameter a 
-        :class:`~azure.storage.common.models.RetryContext` object. Returns the number
+        :class:`~.models.RetryContext` object. Returns the number
         of seconds to wait before retrying the request, or None to indicate not 
         to retry.
-    :ivar ~azure.storage.common.models.LocationMode location_mode:
+    :ivar ~.models.LocationMode location_mode:
         The host location to use to make requests. Defaults to LocationMode.PRIMARY.
         Note that this setting only applies to RA-GRS accounts as other account 
         types do not allow reading from secondary. If the location_mode is set to 
@@ -104,6 +106,7 @@ class StorageClient(object):
         self.account_name = connection_params.account_name
         self.account_key = connection_params.account_key
         self.sas_token = connection_params.sas_token
+        self.token_credential = connection_params.token_credential
         self.is_emulated = connection_params.is_emulated
 
         self.primary_endpoint = connection_params.primary_endpoint
@@ -207,7 +210,7 @@ class StorageClient(object):
         else:
             return ""
 
-    def _perform_request(self, request, parser=None, parser_args=None, operation_context=None):
+    def _perform_request(self, request, parser=None, parser_args=None, operation_context=None, expected_errors=None):
         '''
         Sends the request and return response. Catches HTTPError and hands it
         to error handler
@@ -216,6 +219,14 @@ class StorageClient(object):
         retry_context = RetryContext()
         retry_context.is_emulated = self.is_emulated
 
+        # if request body is a stream, we need to remember its current position in case retries happen
+        if hasattr(request.body, 'read'):
+            try:
+                retry_context.body_position = request.body.tell()
+            except (AttributeError, UnsupportedOperation):
+                # if body position cannot be obtained, then retries will not work
+                pass
+
         # Apply the appropriate host based on the location mode
         self._apply_host(request, operation_context, retry_context)
 
@@ -235,7 +246,13 @@ class StorageClient(object):
                     # callback. This also ensures retry policies with long back offs 
                     # will work as it resets the time sensitive headers.
                     _add_date_header(request)
-                    self.authentication.sign_request(request)
+
+                    try:
+                        # request can be signed individually
+                        self.authentication.sign_request(request)
+                    except AttributeError:
+                        # session can also be signed
+                        self.request_session = self.authentication.signed_session(self.request_session)
 
                     # Set the request context
                     retry_context.request = request
@@ -265,7 +282,7 @@ class StorageClient(object):
                                 self.extract_date_and_request_id(retry_context),
                                 response.status,
                                 response.message,
-                                str(request.headers).replace('\n', ''))
+                                str(response.headers).replace('\n', ''))
 
                     # Parse and wrap HTTP errors in AzureHttpError which inherits from AzureException
                     if response.status >= 300:
@@ -309,6 +326,16 @@ class StorageClient(object):
                     status_code = retry_context.response.status if retry_context.response is not None else 'Unknown'
                     timestamp_and_request_id = self.extract_date_and_request_id(retry_context)
 
+                # if the http error was expected, we should short-circuit
+                if isinstance(ex, AzureHttpError) and expected_errors is not None and ex.error_code in expected_errors:
+                    logger.info("%s Received expected http error: "
+                                "%s, HTTP status code=%s, Exception=%s.",
+                                client_request_id_prefix,
+                                timestamp_and_request_id,
+                                status_code,
+                                exception_str_in_one_line)
+                    raise ex
+
                 logger.info("%s Operation failed: checking if the operation should be retried. "
                             "Current retry count=%s, %s, HTTP status code=%s, Exception=%s.",
                             client_request_id_prefix,
@@ -360,4 +387,5 @@ class StorageClient(object):
                     # note: to cover the emulator scenario, the host_location is grabbed
                     # from request.host_locations(which includes the dev account name)
                     # instead of request.host(which at this point no longer includes the dev account name)
-                    operation_context.host_location = {retry_context.location_mode: request.host_locations[retry_context.location_mode]}
+                    operation_context.host_location = {
+                        retry_context.location_mode: request.host_locations[retry_context.location_mode]}
